@@ -1,12 +1,6 @@
-from typing import Union
-
 import requests
 from requests import Response
 
-from data_classes.FileData import FileData
-from data_classes.ModpackData import ModpackData
-from data_classes.UserData import UserData
-
 
 class Utils:
     @staticmethod
@@ -20,8 +14,8 @@ class Utils:
         return removed
 
     @staticmethod
-    def dictToClass(data: dict, obj: Union[type(ModpackData), type(FileData), type(UserData)]) -> Union[ModpackData, FileData, UserData]:
-        cls: Union[ModpackData, FileData, UserData] = obj()
+    def dictToClass(data: dict, obj):
+        cls = obj()
         for k, v in data.items():
             cls.__setattr__(k, v)
         return cls
